"""
Program to display a square and some circles, moving the square into the circles removes them
from the canvas

Written by Frankie Cerkvenik based on examples by Chris Piech and Mehran Sahami 2023
"""
import random
import time

from graphics import Canvas

CANVAS_WIDTH = 600
CANVAS_HEIGHT = 600
SQUARE_SIZE = 80
DELAY = 1/120


def main():
    canvas = Canvas(CANVAS_WIDTH, CANVAS_HEIGHT, 'Move Square')

    start_y = CANVAS_HEIGHT / 2 - SQUARE_SIZE / 2
    end_y = start_y + SQUARE_SIZE
    rect = canvas.create_rectangle(0, start_y, SQUARE_SIZE, end_y, 'black')

    # make 10 randomly placed circles
    circles = [] # important to remember all our circle objects
    for i in range(10):
        x = random.randint(0, CANVAS_WIDTH)
        y = random.randint(0, CANVAS_HEIGHT)
        size = random.randint(20, 80)
        circle = canvas.create_oval(x, y, x + size, y + size, "blue")
        circles.append(circle)

    while len(circles) != 0:
        # get mouse position
        x = canvas.get_mouse_x()
        y = canvas.get_mouse_y()

        #use move_to not move because we have a position not an offset
        canvas.move_to(rect, x, y)

        # see if we hit a circle
        # get all objects in the same rect as our square
        hits = canvas.find_overlapping(x, y, x + SQUARE_SIZE, y + SQUARE_SIZE)
        for elem in hits:
            if elem in circles: # make sure not to delete our square!
                canvas.delete(elem)
                # remove from the circles list too so we know when we're done!
                circles.remove(elem)

        canvas.update()
        time.sleep(DELAY)

    print("Winner!")
    canvas.mainloop()

if __name__ == '__main__':
    main()
