#!/usr/bin/env python3

"""
A program to make a bunch of new dvd logo images of different colors
based off of a red DVD logo - I recommend running this only with
img/dvd_base.png, but you could add to or change the colors array in main
to make more/different colors!

Run like this:
python3 make_dvds.py img/base_dvd.png

Then manually save the images that show up bc SimpleImage doesn't haven a save :(

Written by Frankie Cerkvenik 2023
"""

import sys
from simpleimage import SimpleImage
import random
def make_color(filename, color):
    """
    Given the filename of an image, create and return another image where each pixel
    in the returned image is red, green or blue depending on the most dominant color
    in the original image. If it is a tie, leave the pixel its original color.
    """
    image = SimpleImage(filename)
    # looping over rows, but could loop over columns
    for y in range(image.height):
        for x in range(image.width):
            # current pixel
            r, g, b = color
            pixel = image.get_pixel(x, y)
            if pixel.blue == 0 and pixel.green == 0 and pixel.red == 255:
                # Using the decomposed functions with returns
                pixel.red = r
                pixel.green = g
                pixel.green = g
                pixel.blue = b
            else:
                pixel.red = 255
                pixel.green = 255
                pixel.blue = 255

    return image

def main():
    args = sys.argv[1:]

    # args:
    # front-image back-image         - do front strategy
    # front-image shift-x back-image - do back strategy
    colors = [
        (255, 0, 255),  # Neon Pink
        (255, 255, 0),  # Neon Yellow
        (0, 255, 0),  # Neon Green
        (0, 255, 255),  # Neon Cyan
        (255, 0, 0),  # Neon Red
        (0, 0, 255),  # Neon Blue
        (255, 128, 0),  # Neon Orange
        (128, 0, 255),  # Neon Purple
        (0, 128, 128),  # Neon Teal
        (255, 0, 128),  # Neon Fuchsia
        (0, 255, 128),  # Neon Lime
        (128, 255, 0),  # Neon Chartreuse
        (255, 128, 128),  # Neon Salmon
        (128, 255, 128),  # Neon Spring Green
        (128, 128, 255),  # Neon Indigo
        (255, 128, 255),  # Neon Magenta
        (128, 255, 255),  # Neon Aqua
        (255, 255, 128),  # Neon Lemon
        (128, 128, 128),  # Neon Gray
    ]
    if len(args) == 1:
        for i in range(0, 10):
            image = make_color(args[0], colors[i])
            image.show()
    else:
        print("Please run with one filename like 'python rgb-ify_soln.py stanford-600.jpg")



if __name__ == '__main__':
    main()
